/****************************************************************************
** Meta object code from reading C++ file 'unit.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../artikulate-26.04.0/src/core/unit.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'unit.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4UnitE_t {};
} // unnamed namespace

template <> constexpr inline auto Unit::qt_create_metaobjectdata<qt_meta_tag_ZN4UnitE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Unit",
        "idChanged",
        "titleChanged",
        "id",
        "title"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'id'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0x70000000 | 1),
        // property 'title'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0x70000000 | 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Unit, qt_meta_tag_ZN4UnitE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Unit::staticMetaObject = { {
    QMetaObject::SuperData::link<IEditableUnit::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4UnitE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4UnitE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4UnitE_t>.metaTypes,
    nullptr
} };

void Unit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Unit *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->id(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setId(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setTitle(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Unit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Unit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4UnitE_t>.strings))
        return static_cast<void*>(this);
    return IEditableUnit::qt_metacast(_clname);
}

int Unit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = IEditableUnit::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}
namespace CheckNotifySignalValidity_ZN4UnitE {
template<typename T> using has_nullary_idChanged = decltype(std::declval<T>().idChanged());
template<typename T> using has_unary_idChanged = decltype(std::declval<T>().idChanged(std::declval<QString>()));
static_assert(qxp::is_detected_v<has_nullary_idChanged, Unit> || qxp::is_detected_v<has_unary_idChanged, Unit>,
              "NOTIFY signal idChanged does not exist in class (or is private in its parent)");
template<typename T> using has_nullary_titleChanged = decltype(std::declval<T>().titleChanged());
template<typename T> using has_unary_titleChanged = decltype(std::declval<T>().titleChanged(std::declval<QString>()));
static_assert(qxp::is_detected_v<has_nullary_titleChanged, Unit> || qxp::is_detected_v<has_unary_titleChanged, Unit>,
              "NOTIFY signal titleChanged does not exist in class (or is private in its parent)");
}
QT_WARNING_POP
