/****************************************************************************
** Meta object code from reading C++ file 'languagemodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../artikulate-26.04.0/src/org/kde/artikulate/languagemodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'languagemodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13LanguageModelE_t {};
} // unnamed namespace

template <> constexpr inline auto LanguageModel::qt_create_metaobjectdata<qt_meta_tag_ZN13LanguageModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LanguageModel",
        "QML.Element",
        "auto",
        "resourceModelChanged",
        "",
        "viewChanged",
        "language",
        "QVariant",
        "index",
        "resourceModel",
        "LanguageResourceModel*",
        "view",
        "LanguageResourceView",
        "NonEmptyContributorOnlyResources",
        "NonEmptyGhnsOnlyLanguages",
        "NonEmptyLanguages",
        "AllLanguages"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'resourceModelChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'viewChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'language'
        QtMocHelpers::MethodData<QVariant(int) const>(6, 4, QMC::AccessPublic, 0x80000000 | 7, {{
            { QMetaType::Int, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'resourceModel'
        QtMocHelpers::PropertyData<LanguageResourceModel*>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'view'
        QtMocHelpers::PropertyData<enum LanguageResourceView>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'LanguageResourceView'
        QtMocHelpers::EnumData<enum LanguageResourceView>(12, 12, QMC::EnumFlags{}).add({
            {   13, LanguageResourceView::NonEmptyContributorOnlyResources },
            {   14, LanguageResourceView::NonEmptyGhnsOnlyLanguages },
            {   15, LanguageResourceView::NonEmptyLanguages },
            {   16, LanguageResourceView::AllLanguages },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<LanguageModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject LanguageModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QSortFilterProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13LanguageModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13LanguageModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13LanguageModelE_t>.metaTypes,
    nullptr
} };

void LanguageModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LanguageModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->resourceModelChanged(); break;
        case 1: _t->viewChanged(); break;
        case 2: { QVariant _r = _t->language((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LanguageModel::*)()>(_a, &LanguageModel::resourceModelChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LanguageModel::*)()>(_a, &LanguageModel::viewChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<LanguageResourceModel**>(_v) = _t->resourceModel(); break;
        case 1: *reinterpret_cast<enum LanguageResourceView*>(_v) = _t->view(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setResourceModel(*reinterpret_cast<LanguageResourceModel**>(_v)); break;
        case 1: _t->setView(*reinterpret_cast<enum LanguageResourceView*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *LanguageModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LanguageModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13LanguageModelE_t>.strings))
        return static_cast<void*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int LanguageModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void LanguageModel::resourceModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void LanguageModel::viewChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
