/****************************************************************************
** Meta object code from reading C++ file 'learninggoalmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../artikulate-26.04.0/liblearnerprofile/src/models/learninggoalmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'learninggoalmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14LearnerProfile17LearningGoalModelE_t {};
} // unnamed namespace

template <> constexpr inline auto LearnerProfile::LearningGoalModel::qt_create_metaobjectdata<qt_meta_tag_ZN14LearnerProfile17LearningGoalModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LearnerProfile::LearningGoalModel",
        "profileManagerChanged",
        "",
        "learnerChanged",
        "learningGoalChanged",
        "index",
        "onLearningGoalAboutToBeAdded",
        "LearningGoal*",
        "goal",
        "onLearningGoalAdded",
        "onLearningGoalAboutToBeRemoved",
        "emitLearningGoalChanged",
        "row",
        "learningGoal",
        "QVariant",
        "profileManager",
        "LearnerProfile::ProfileManager*",
        "learner",
        "LearnerProfile::Learner*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'profileManagerChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'learnerChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'learningGoalChanged'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'onLearningGoalAboutToBeAdded'
        QtMocHelpers::SlotData<void(LearningGoal *, int)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::Int, 5 },
        }}),
        // Slot 'onLearningGoalAdded'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onLearningGoalAboutToBeRemoved'
        QtMocHelpers::SlotData<void(int)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'emitLearningGoalChanged'
        QtMocHelpers::SlotData<void(int)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Method 'learningGoal'
        QtMocHelpers::MethodData<QVariant(int) const>(13, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::Int, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'profileManager'
        QtMocHelpers::PropertyData<LearnerProfile::ProfileManager*>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'learner'
        QtMocHelpers::PropertyData<LearnerProfile::Learner*>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LearningGoalModel, qt_meta_tag_ZN14LearnerProfile17LearningGoalModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LearnerProfile::LearningGoalModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14LearnerProfile17LearningGoalModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14LearnerProfile17LearningGoalModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14LearnerProfile17LearningGoalModelE_t>.metaTypes,
    nullptr
} };

void LearnerProfile::LearningGoalModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LearningGoalModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->profileManagerChanged(); break;
        case 1: _t->learnerChanged(); break;
        case 2: _t->learningGoalChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->onLearningGoalAboutToBeAdded((*reinterpret_cast<std::add_pointer_t<LearningGoal*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->onLearningGoalAdded(); break;
        case 5: _t->onLearningGoalAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->emitLearningGoalChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: { QVariant _r = _t->learningGoal((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< LearningGoal* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LearningGoalModel::*)()>(_a, &LearningGoalModel::profileManagerChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LearningGoalModel::*)()>(_a, &LearningGoalModel::learnerChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (LearningGoalModel::*)(int )>(_a, &LearningGoalModel::learningGoalChanged, 2))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< LearnerProfile::ProfileManager* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<LearnerProfile::ProfileManager**>(_v) = _t->profileManager(); break;
        case 1: *reinterpret_cast<LearnerProfile::Learner**>(_v) = _t->learner(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setProfileManager(*reinterpret_cast<LearnerProfile::ProfileManager**>(_v)); break;
        case 1: _t->setLearner(*reinterpret_cast<LearnerProfile::Learner**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *LearnerProfile::LearningGoalModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LearnerProfile::LearningGoalModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14LearnerProfile17LearningGoalModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int LearnerProfile::LearningGoalModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void LearnerProfile::LearningGoalModel::profileManagerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void LearnerProfile::LearningGoalModel::learnerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void LearnerProfile::LearningGoalModel::learningGoalChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
