/****************************************************************************
** Meta object code from reading C++ file 'phrase.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../artikulate-26.04.0/src/core/phrase.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'phrase.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6PhraseE_t {};
} // unnamed namespace

template <> constexpr inline auto Phrase::qt_create_metaobjectdata<qt_meta_tag_ZN6PhraseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Phrase",
        "progressChanged",
        "",
        "excludedChanged",
        "markSoundRecorded",
        "soundFileOutputPath",
        "hasPhoneme",
        "Phoneme*",
        "phoneme",
        "addPhoneme",
        "removePhoneme",
        "idChanged",
        "textChanged",
        "i18nTextChanged",
        "typeChanged",
        "editStateChanged",
        "id",
        "text",
        "i18nText",
        "type",
        "IPhrase::Type",
        "editState",
        "Phrase::EditState",
        "excluded",
        "progress",
        "Progress",
        "Skip",
        "Done"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'progressChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'excludedChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'markSoundRecorded'
        QtMocHelpers::MethodData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'soundFileOutputPath'
        QtMocHelpers::MethodData<QString() const>(5, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'hasPhoneme'
        QtMocHelpers::MethodData<bool(Phoneme *)>(6, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Method 'addPhoneme'
        QtMocHelpers::MethodData<void(Phoneme *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Method 'removePhoneme'
        QtMocHelpers::MethodData<void(Phoneme *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'id'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0x70000000 | 11),
        // property 'text'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0x70000000 | 12),
        // property 'i18nText'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0x70000000 | 13),
        // property 'type'
        QtMocHelpers::PropertyData<IPhrase::Type>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0x70000000 | 14),
        // property 'editState'
        QtMocHelpers::PropertyData<Phrase::EditState>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0x70000000 | 15),
        // property 'excluded'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'progress'
        QtMocHelpers::PropertyData<int>(24, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Progress'
        QtMocHelpers::EnumData<enum Progress>(25, 25, QMC::EnumIsScoped).add({
            {   26, Progress::Skip },
            {   27, Progress::Done },
        }),
    };
    return QtMocHelpers::metaObjectData<Phrase, qt_meta_tag_ZN6PhraseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN6PhraseE[] = {
    QMetaObject::SuperData::link<IPhrase::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject Phrase::staticMetaObject = { {
    QMetaObject::SuperData::link<IEditablePhrase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6PhraseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6PhraseE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN6PhraseE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6PhraseE_t>.metaTypes,
    nullptr
} };

void Phrase::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Phrase *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->progressChanged(); break;
        case 1: _t->excludedChanged(); break;
        case 2: _t->markSoundRecorded(); break;
        case 3: { QString _r = _t->soundFileOutputPath();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->hasPhoneme((*reinterpret_cast<std::add_pointer_t<Phoneme*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->addPhoneme((*reinterpret_cast<std::add_pointer_t<Phoneme*>>(_a[1]))); break;
        case 6: _t->removePhoneme((*reinterpret_cast<std::add_pointer_t<Phoneme*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Phrase::*)()>(_a, &Phrase::progressChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Phrase::*)()>(_a, &Phrase::excludedChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->id(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->text(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->i18nText(); break;
        case 3: *reinterpret_cast<IPhrase::Type*>(_v) = _t->type(); break;
        case 4: *reinterpret_cast<Phrase::EditState*>(_v) = _t->editState(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isExcluded(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->progress(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setId(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setText(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->seti18nText(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setType(*reinterpret_cast<IPhrase::Type*>(_v)); break;
        case 4: _t->setEditState(*reinterpret_cast<Phrase::EditState*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Phrase::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Phrase::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6PhraseE_t>.strings))
        return static_cast<void*>(this);
    return IEditablePhrase::qt_metacast(_clname);
}

int Phrase::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = IEditablePhrase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void Phrase::progressChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Phrase::excludedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace CheckNotifySignalValidity_ZN6PhraseE {
template<typename T> using has_nullary_idChanged = decltype(std::declval<T>().idChanged());
template<typename T> using has_unary_idChanged = decltype(std::declval<T>().idChanged(std::declval<QString>()));
static_assert(qxp::is_detected_v<has_nullary_idChanged, Phrase> || qxp::is_detected_v<has_unary_idChanged, Phrase>,
              "NOTIFY signal idChanged does not exist in class (or is private in its parent)");
template<typename T> using has_nullary_textChanged = decltype(std::declval<T>().textChanged());
template<typename T> using has_unary_textChanged = decltype(std::declval<T>().textChanged(std::declval<QString>()));
static_assert(qxp::is_detected_v<has_nullary_textChanged, Phrase> || qxp::is_detected_v<has_unary_textChanged, Phrase>,
              "NOTIFY signal textChanged does not exist in class (or is private in its parent)");
template<typename T> using has_nullary_i18nTextChanged = decltype(std::declval<T>().i18nTextChanged());
template<typename T> using has_unary_i18nTextChanged = decltype(std::declval<T>().i18nTextChanged(std::declval<QString>()));
static_assert(qxp::is_detected_v<has_nullary_i18nTextChanged, Phrase> || qxp::is_detected_v<has_unary_i18nTextChanged, Phrase>,
              "NOTIFY signal i18nTextChanged does not exist in class (or is private in its parent)");
template<typename T> using has_nullary_typeChanged = decltype(std::declval<T>().typeChanged());
template<typename T> using has_unary_typeChanged = decltype(std::declval<T>().typeChanged(std::declval<IPhrase::Type>()));
static_assert(qxp::is_detected_v<has_nullary_typeChanged, Phrase> || qxp::is_detected_v<has_unary_typeChanged, Phrase>,
              "NOTIFY signal typeChanged does not exist in class (or is private in its parent)");
template<typename T> using has_nullary_editStateChanged = decltype(std::declval<T>().editStateChanged());
template<typename T> using has_unary_editStateChanged = decltype(std::declval<T>().editStateChanged(std::declval<Phrase::EditState>()));
static_assert(qxp::is_detected_v<has_nullary_editStateChanged, Phrase> || qxp::is_detected_v<has_unary_editStateChanged, Phrase>,
              "NOTIFY signal editStateChanged does not exist in class (or is private in its parent)");
}
QT_WARNING_POP
