/****************************************************************************
** Meta object code from reading C++ file 'editorsession.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../artikulate-26.04.0/src/org/kde/artikulate/editorsession.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'editorsession.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13EditorSessionE_t {};
} // unnamed namespace

template <> constexpr inline auto EditorSession::qt_create_metaobjectdata<qt_meta_tag_ZN13EditorSessionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EditorSession",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "skeletonModeChanged",
        "",
        "languageChanged",
        "unitChanged",
        "repositoryChanged",
        "switchToPreviousPhrase",
        "switchToNextPhrase",
        "updateCourseFromSkeleton",
        "courseChanged",
        "phraseChanged",
        "skeletonMode",
        "language",
        "ILanguage*",
        "course",
        "IEditableCourse*",
        "unit",
        "IUnit*",
        "phrase",
        "IPhrase*",
        "hasNextPhrase",
        "hasPreviousPhrase",
        "repository",
        "IEditableRepository*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'skeletonModeChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'languageChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'unitChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'repositoryChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'switchToPreviousPhrase'
        QtMocHelpers::MethodData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'switchToNextPhrase'
        QtMocHelpers::MethodData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'updateCourseFromSkeleton'
        QtMocHelpers::MethodData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'skeletonMode'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'language'
        QtMocHelpers::PropertyData<ILanguage*>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'course'
        QtMocHelpers::PropertyData<IEditableCourse*>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0x70000000 | 13),
        // property 'unit'
        QtMocHelpers::PropertyData<IUnit*>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'phrase'
        QtMocHelpers::PropertyData<IPhrase*>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 0x70000000 | 14),
        // property 'hasNextPhrase'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags, 0x70000000 | 14),
        // property 'hasPreviousPhrase'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags, 0x70000000 | 14),
        // property 'repository'
        QtMocHelpers::PropertyData<IEditableRepository*>(26, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<EditorSession, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject EditorSession::staticMetaObject = { {
    QMetaObject::SuperData::link<ISessionActions::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13EditorSessionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13EditorSessionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13EditorSessionE_t>.metaTypes,
    nullptr
} };

void EditorSession::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EditorSession *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->skeletonModeChanged(); break;
        case 1: _t->languageChanged(); break;
        case 2: _t->unitChanged(); break;
        case 3: _t->repositoryChanged(); break;
        case 4: _t->switchToPreviousPhrase(); break;
        case 5: _t->switchToNextPhrase(); break;
        case 6: _t->updateCourseFromSkeleton(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (EditorSession::*)()>(_a, &EditorSession::skeletonModeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditorSession::*)()>(_a, &EditorSession::languageChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditorSession::*)()>(_a, &EditorSession::unitChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditorSession::*)()>(_a, &EditorSession::repositoryChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IEditableCourse* >(); break;
        case 7:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IEditableRepository* >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ILanguage* >(); break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IPhrase* >(); break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IUnit* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->skeletonMode(); break;
        case 1: *reinterpret_cast<ILanguage**>(_v) = _t->language(); break;
        case 2: *reinterpret_cast<IEditableCourse**>(_v) = _t->course(); break;
        case 3: *reinterpret_cast<IUnit**>(_v) = _t->activeUnit(); break;
        case 4: *reinterpret_cast<IPhrase**>(_v) = _t->activePhrase(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->hasNextPhrase(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->hasPreviousPhrase(); break;
        case 7: *reinterpret_cast<IEditableRepository**>(_v) = _t->repository(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setCourse(*reinterpret_cast<IEditableCourse**>(_v)); break;
        case 4: _t->setActivePhrase(*reinterpret_cast<IPhrase**>(_v)); break;
        case 7: _t->setRepository(*reinterpret_cast<IEditableRepository**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *EditorSession::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EditorSession::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13EditorSessionE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "ISessionActions"))
        return static_cast< ISessionActions*>(this);
    return ISessionActions::qt_metacast(_clname);
}

int EditorSession::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ISessionActions::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void EditorSession::skeletonModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void EditorSession::languageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void EditorSession::unitChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void EditorSession::repositoryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
namespace CheckNotifySignalValidity_ZN13EditorSessionE {
template<typename T> using has_nullary_courseChanged = decltype(std::declval<T>().courseChanged());
template<typename T> using has_unary_courseChanged = decltype(std::declval<T>().courseChanged(std::declval<IEditableCourse*>()));
static_assert(qxp::is_detected_v<has_nullary_courseChanged, EditorSession> || qxp::is_detected_v<has_unary_courseChanged, EditorSession>,
              "NOTIFY signal courseChanged does not exist in class (or is private in its parent)");
template<typename T> using has_nullary_phraseChanged = decltype(std::declval<T>().phraseChanged());
template<typename T> using has_unary_phraseChanged = decltype(std::declval<T>().phraseChanged(std::declval<IPhrase*>()));
static_assert(qxp::is_detected_v<has_nullary_phraseChanged, EditorSession> || qxp::is_detected_v<has_unary_phraseChanged, EditorSession>,
              "NOTIFY signal phraseChanged does not exist in class (or is private in its parent)");
}
QT_WARNING_POP
