/****************************************************************************
** Meta object code from reading C++ file 'iunit.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../artikulate-26.04.0/src/core/iunit.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'iunit.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5IUnitE_t {};
} // unnamed namespace

template <> constexpr inline auto IUnit::qt_create_metaobjectdata<qt_meta_tag_ZN5IUnitE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "IUnit",
        "idChanged",
        "",
        "titleChanged",
        "courseChanged",
        "displayPhraseTypeChanged",
        "modified",
        "phraseAboutToBeAdded",
        "std::shared_ptr<IPhrase>",
        "phraseAdded",
        "phraseAboutToBeRemoved",
        "phraseRemoved",
        "id",
        "title",
        "i18nTitle"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'idChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'courseChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'displayPhraseTypeChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modified'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'phraseAboutToBeAdded'
        QtMocHelpers::SignalData<void(std::shared_ptr<IPhrase>, int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'phraseAdded'
        QtMocHelpers::SignalData<void(std::shared_ptr<IPhrase>)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Signal 'phraseAboutToBeRemoved'
        QtMocHelpers::SignalData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'phraseRemoved'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'id'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'title'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'i18nTitle'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<IUnit, qt_meta_tag_ZN5IUnitE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject IUnit::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5IUnitE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5IUnitE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5IUnitE_t>.metaTypes,
    nullptr
} };

void IUnit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IUnit *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->idChanged(); break;
        case 1: _t->titleChanged(); break;
        case 2: _t->courseChanged(); break;
        case 3: _t->displayPhraseTypeChanged(); break;
        case 4: _t->modified(); break;
        case 5: _t->phraseAboutToBeAdded((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<IPhrase>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 6: _t->phraseAdded((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<IPhrase>>>(_a[1]))); break;
        case 7: _t->phraseAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->phraseRemoved(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (IUnit::*)()>(_a, &IUnit::idChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (IUnit::*)()>(_a, &IUnit::titleChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (IUnit::*)()>(_a, &IUnit::courseChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (IUnit::*)()>(_a, &IUnit::displayPhraseTypeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (IUnit::*)()>(_a, &IUnit::modified, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (IUnit::*)(std::shared_ptr<IPhrase> , int )>(_a, &IUnit::phraseAboutToBeAdded, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (IUnit::*)(std::shared_ptr<IPhrase> )>(_a, &IUnit::phraseAdded, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (IUnit::*)(int )>(_a, &IUnit::phraseAboutToBeRemoved, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (IUnit::*)()>(_a, &IUnit::phraseRemoved, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->id(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->i18nTitle(); break;
        default: break;
        }
    }
}

const QMetaObject *IUnit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IUnit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5IUnitE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int IUnit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void IUnit::idChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void IUnit::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void IUnit::courseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void IUnit::displayPhraseTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void IUnit::modified()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void IUnit::phraseAboutToBeAdded(std::shared_ptr<IPhrase> _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void IUnit::phraseAdded(std::shared_ptr<IPhrase> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void IUnit::phraseAboutToBeRemoved(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void IUnit::phraseRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
