/****************************************************************************
** Meta object code from reading C++ file 'editablecourseresource.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../artikulate-26.04.0/src/core/resources/editablecourseresource.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'editablecourseresource.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22EditableCourseResourceE_t {};
} // unnamed namespace

template <> constexpr inline auto EditableCourseResource::qt_create_metaobjectdata<qt_meta_tag_ZN22EditableCourseResourceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EditableCourseResource",
        "idChanged",
        "",
        "foreignIdChanged",
        "titleChanged",
        "i18nTitleChanged",
        "descriptionChanged",
        "languageChanged",
        "markModified",
        "createUnit",
        "Unit*",
        "createPhraseAfter",
        "IPhrase*",
        "previousPhrase",
        "deletePhrase",
        "phrase"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'idChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'foreignIdChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'i18nTitleChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'descriptionChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'languageChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'markModified'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'createUnit'
        QtMocHelpers::MethodData<Unit *()>(9, 2, QMC::AccessPublic, 0x80000000 | 10),
        // Method 'createPhraseAfter'
        QtMocHelpers::MethodData<bool(IPhrase *)>(11, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Method 'deletePhrase'
        QtMocHelpers::MethodData<bool(IPhrase *)>(14, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 12, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EditableCourseResource, qt_meta_tag_ZN22EditableCourseResourceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EditableCourseResource::staticMetaObject = { {
    QMetaObject::SuperData::link<IEditableCourse::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22EditableCourseResourceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22EditableCourseResourceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22EditableCourseResourceE_t>.metaTypes,
    nullptr
} };

void EditableCourseResource::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EditableCourseResource *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->idChanged(); break;
        case 1: _t->foreignIdChanged(); break;
        case 2: _t->titleChanged(); break;
        case 3: _t->i18nTitleChanged(); break;
        case 4: _t->descriptionChanged(); break;
        case 5: _t->languageChanged(); break;
        case 6: _t->markModified(); break;
        case 7: { Unit* _r = _t->createUnit();
            if (_a[0]) *reinterpret_cast<Unit**>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->createPhraseAfter((*reinterpret_cast<std::add_pointer_t<IPhrase*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->deletePhrase((*reinterpret_cast<std::add_pointer_t<IPhrase*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (EditableCourseResource::*)()>(_a, &EditableCourseResource::idChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditableCourseResource::*)()>(_a, &EditableCourseResource::foreignIdChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditableCourseResource::*)()>(_a, &EditableCourseResource::titleChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditableCourseResource::*)()>(_a, &EditableCourseResource::i18nTitleChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditableCourseResource::*)()>(_a, &EditableCourseResource::descriptionChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditableCourseResource::*)()>(_a, &EditableCourseResource::languageChanged, 5))
            return;
    }
}

const QMetaObject *EditableCourseResource::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EditableCourseResource::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22EditableCourseResourceE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "com.kde.artikulate.ICourse/1.0"))
        return static_cast< ICourse*>(this);
    if (!strcmp(_clname, "com.kde.artikulate.IEditableCourse/1.0"))
        return static_cast< IEditableCourse*>(this);
    return IEditableCourse::qt_metacast(_clname);
}

int EditableCourseResource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = IEditableCourse::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void EditableCourseResource::idChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void EditableCourseResource::foreignIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void EditableCourseResource::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void EditableCourseResource::i18nTitleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void EditableCourseResource::descriptionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void EditableCourseResource::languageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
