/****************************************************************************
** Meta object code from reading C++ file 'phonemeunitmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../artikulate-26.04.0/src/org/kde/artikulate/phonemeunitmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'phonemeunitmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16PhonemeUnitModelE_t {};
} // unnamed namespace

template <> constexpr inline auto PhonemeUnitModel::qt_create_metaobjectdata<qt_meta_tag_ZN16PhonemeUnitModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PhonemeUnitModel",
        "QML.Element",
        "auto",
        "unitChanged",
        "",
        "index",
        "courseChanged",
        "phonemeGroupChanged",
        "countChanged",
        "onUnitAboutToBeAdded",
        "PhonemeGroup*",
        "phonemeGroup",
        "onUnitAdded",
        "onUnitsAboutToBeRemoved",
        "first",
        "last",
        "onUnitsRemoved",
        "onUnitChanged",
        "row",
        "course",
        "ICourse*",
        "count"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'unitChanged'
        QtMocHelpers::SignalData<void(int)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'courseChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'phonemeGroupChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'countChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onUnitAboutToBeAdded'
        QtMocHelpers::SlotData<void(PhonemeGroup *, int)>(9, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { QMetaType::Int, 5 },
        }}),
        // Slot 'onUnitAdded'
        QtMocHelpers::SlotData<void()>(12, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onUnitsAboutToBeRemoved'
        QtMocHelpers::SlotData<void(int, int)>(13, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 14 }, { QMetaType::Int, 15 },
        }}),
        // Slot 'onUnitsRemoved'
        QtMocHelpers::SlotData<void()>(16, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onUnitChanged'
        QtMocHelpers::SlotData<void(int)>(17, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'course'
        QtMocHelpers::PropertyData<ICourse*>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'phonemeGroup'
        QtMocHelpers::PropertyData<PhonemeGroup*>(11, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'count'
        QtMocHelpers::PropertyData<int>(21, QMetaType::Int, QMC::DefaultPropertyFlags, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<PhonemeUnitModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PhonemeUnitModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16PhonemeUnitModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16PhonemeUnitModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16PhonemeUnitModelE_t>.metaTypes,
    nullptr
} };

void PhonemeUnitModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PhonemeUnitModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->unitChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->courseChanged(); break;
        case 2: _t->phonemeGroupChanged(); break;
        case 3: _t->countChanged(); break;
        case 4: _t->onUnitAboutToBeAdded((*reinterpret_cast<std::add_pointer_t<PhonemeGroup*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 5: _t->onUnitAdded(); break;
        case 6: _t->onUnitsAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 7: _t->onUnitsRemoved(); break;
        case 8: _t->onUnitChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PhonemeUnitModel::*)(int )>(_a, &PhonemeUnitModel::unitChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PhonemeUnitModel::*)()>(_a, &PhonemeUnitModel::courseChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PhonemeUnitModel::*)()>(_a, &PhonemeUnitModel::phonemeGroupChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PhonemeUnitModel::*)()>(_a, &PhonemeUnitModel::countChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<ICourse**>(_v) = _t->course(); break;
        case 1: *reinterpret_cast<PhonemeGroup**>(_v) = _t->phonemeGroup(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->count(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCourse(*reinterpret_cast<ICourse**>(_v)); break;
        case 1: _t->setPhonemeGroup(*reinterpret_cast<PhonemeGroup**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PhonemeUnitModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PhonemeUnitModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16PhonemeUnitModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int PhonemeUnitModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void PhonemeUnitModel::unitChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PhonemeUnitModel::courseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PhonemeUnitModel::phonemeGroupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PhonemeUnitModel::countChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
