/****************************************************************************
** Meta object code from reading C++ file 'trainingsession.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../artikulate-26.04.0/src/org/kde/artikulate/trainingsession.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'trainingsession.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15TrainingSessionE_t {};
} // unnamed namespace

template <> constexpr inline auto TrainingSession::qt_create_metaobjectdata<qt_meta_tag_ZN15TrainingSessionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TrainingSession",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "completed",
        "",
        "closeUnit",
        "trainingStarted",
        "accept",
        "skip",
        "courseChanged",
        "phraseChanged",
        "course",
        "ICourse*",
        "unit",
        "IUnit*",
        "phrase",
        "IPhrase*",
        "hasNext"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'completed'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'closeUnit'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trainingStarted'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'accept'
        QtMocHelpers::MethodData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'skip'
        QtMocHelpers::MethodData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'course'
        QtMocHelpers::PropertyData<ICourse*>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0x70000000 | 11),
        // property 'unit'
        QtMocHelpers::PropertyData<IUnit*>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0x70000000 | 12),
        // property 'phrase'
        QtMocHelpers::PropertyData<IPhrase*>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 0x70000000 | 12),
        // property 'hasNext'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags, 0x70000000 | 12),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<TrainingSession, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TrainingSession::staticMetaObject = { {
    QMetaObject::SuperData::link<ISessionActions::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15TrainingSessionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15TrainingSessionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15TrainingSessionE_t>.metaTypes,
    nullptr
} };

void TrainingSession::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TrainingSession *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->completed(); break;
        case 1: _t->closeUnit(); break;
        case 2: _t->trainingStarted(); break;
        case 3: _t->accept(); break;
        case 4: _t->skip(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TrainingSession::*)()>(_a, &TrainingSession::completed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TrainingSession::*)()>(_a, &TrainingSession::closeUnit, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TrainingSession::*)()>(_a, &TrainingSession::trainingStarted, 2))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IPhrase* >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IUnit* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<ICourse**>(_v) = _t->course(); break;
        case 1: *reinterpret_cast<IUnit**>(_v) = _t->activeUnit(); break;
        case 2: *reinterpret_cast<IPhrase**>(_v) = _t->activePhrase(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->hasNext(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCourse(*reinterpret_cast<ICourse**>(_v)); break;
        case 1: _t->setUnit(*reinterpret_cast<IUnit**>(_v)); break;
        case 2: _t->setActivePhrase(*reinterpret_cast<IPhrase**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *TrainingSession::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TrainingSession::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15TrainingSessionE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "ISessionActions"))
        return static_cast< ISessionActions*>(this);
    return ISessionActions::qt_metacast(_clname);
}

int TrainingSession::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ISessionActions::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void TrainingSession::completed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TrainingSession::closeUnit()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void TrainingSession::trainingStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
namespace CheckNotifySignalValidity_ZN15TrainingSessionE {
template<typename T> using has_nullary_courseChanged = decltype(std::declval<T>().courseChanged());
template<typename T> using has_unary_courseChanged = decltype(std::declval<T>().courseChanged(std::declval<ICourse*>()));
static_assert(qxp::is_detected_v<has_nullary_courseChanged, TrainingSession> || qxp::is_detected_v<has_unary_courseChanged, TrainingSession>,
              "NOTIFY signal courseChanged does not exist in class (or is private in its parent)");
template<typename T> using has_nullary_phraseChanged = decltype(std::declval<T>().phraseChanged());
template<typename T> using has_unary_phraseChanged = decltype(std::declval<T>().phraseChanged(std::declval<IUnit*>()));
static_assert(qxp::is_detected_v<has_nullary_phraseChanged, TrainingSession> || qxp::is_detected_v<has_unary_phraseChanged, TrainingSession>,
              "NOTIFY signal phraseChanged does not exist in class (or is private in its parent)");
}
QT_WARNING_POP
