/****************************************************************************
** Meta object code from reading C++ file 'learner.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../artikulate-26.04.0/liblearnerprofile/src/learner.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'learner.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14LearnerProfile7LearnerE_t {};
} // unnamed namespace

template <> constexpr inline auto LearnerProfile::Learner::qt_create_metaobjectdata<qt_meta_tag_ZN14LearnerProfile7LearnerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LearnerProfile::Learner",
        "nameChanged",
        "",
        "imageChanged",
        "identifierChanged",
        "goalAboutToBeAdded",
        "LearningGoal*",
        "goalAdded",
        "goalAboutToBeRemoved",
        "goalRemoved",
        "Learner*",
        "goalCountChanged",
        "activeGoalChanged",
        "clearImage",
        "addGoal",
        "LearnerProfile::LearningGoal*",
        "goal",
        "removeGoal",
        "hasGoal",
        "setActiveGoal",
        "LearnerProfile::Learner::Category",
        "category",
        "identifier",
        "activeGoal",
        "name",
        "id",
        "imageUrl",
        "goals",
        "QList<LearnerProfile::LearningGoal*>",
        "Category",
        "Unspecified",
        "Language"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'imageChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'identifierChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'goalAboutToBeAdded'
        QtMocHelpers::SignalData<void(LearningGoal *, int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'goalAdded'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'goalAboutToBeRemoved'
        QtMocHelpers::SignalData<void(int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'goalRemoved'
        QtMocHelpers::SignalData<void(Learner *, LearningGoal *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 2 }, { 0x80000000 | 6, 2 },
        }}),
        // Signal 'goalCountChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeGoalChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'clearImage'
        QtMocHelpers::MethodData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'addGoal'
        QtMocHelpers::MethodData<void(LearnerProfile::LearningGoal *)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Method 'removeGoal'
        QtMocHelpers::MethodData<void(LearnerProfile::LearningGoal *)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Method 'hasGoal'
        QtMocHelpers::MethodData<bool(LearnerProfile::LearningGoal *) const>(18, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Method 'setActiveGoal'
        QtMocHelpers::MethodData<void(LearnerProfile::Learner::Category, const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { QMetaType::QString, 22 },
        }}),
        // Method 'activeGoal'
        QtMocHelpers::MethodData<LearnerProfile::LearningGoal *(LearnerProfile::Learner::Category) const>(23, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { 0x80000000 | 20, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'id'
        QtMocHelpers::PropertyData<int>(25, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 2),
        // property 'imageUrl'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'goals'
        QtMocHelpers::PropertyData<QList<LearnerProfile::LearningGoal*>>(27, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 7),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Category'
        QtMocHelpers::EnumData<enum Category>(29, 29, QMC::EnumFlags{}).add({
            {   30, Category::Unspecified },
            {   31, Category::Language },
        }),
    };
    return QtMocHelpers::metaObjectData<Learner, qt_meta_tag_ZN14LearnerProfile7LearnerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LearnerProfile::Learner::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14LearnerProfile7LearnerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14LearnerProfile7LearnerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14LearnerProfile7LearnerE_t>.metaTypes,
    nullptr
} };

void LearnerProfile::Learner::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Learner *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nameChanged(); break;
        case 1: _t->imageChanged(); break;
        case 2: _t->identifierChanged(); break;
        case 3: _t->goalAboutToBeAdded((*reinterpret_cast<std::add_pointer_t<LearningGoal*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->goalAdded(); break;
        case 5: _t->goalAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->goalRemoved((*reinterpret_cast<std::add_pointer_t<Learner*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<LearningGoal*>>(_a[2]))); break;
        case 7: _t->goalCountChanged(); break;
        case 8: _t->activeGoalChanged(); break;
        case 9: _t->clearImage(); break;
        case 10: _t->addGoal((*reinterpret_cast<std::add_pointer_t<LearnerProfile::LearningGoal*>>(_a[1]))); break;
        case 11: _t->removeGoal((*reinterpret_cast<std::add_pointer_t<LearnerProfile::LearningGoal*>>(_a[1]))); break;
        case 12: { bool _r = _t->hasGoal((*reinterpret_cast<std::add_pointer_t<LearnerProfile::LearningGoal*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->setActiveGoal((*reinterpret_cast<std::add_pointer_t<LearnerProfile::Learner::Category>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 14: { LearnerProfile::LearningGoal* _r = _t->activeGoal((*reinterpret_cast<std::add_pointer_t<LearnerProfile::Learner::Category>>(_a[1])));
            if (_a[0]) *reinterpret_cast<LearnerProfile::LearningGoal**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< LearningGoal* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Learner* >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< LearningGoal* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< LearnerProfile::LearningGoal* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< LearnerProfile::LearningGoal* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< LearnerProfile::LearningGoal* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Learner::*)()>(_a, &Learner::nameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Learner::*)()>(_a, &Learner::imageChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Learner::*)()>(_a, &Learner::identifierChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Learner::*)(LearningGoal * , int )>(_a, &Learner::goalAboutToBeAdded, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Learner::*)()>(_a, &Learner::goalAdded, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Learner::*)(int )>(_a, &Learner::goalAboutToBeRemoved, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Learner::*)(Learner * , LearningGoal * )>(_a, &Learner::goalRemoved, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Learner::*)()>(_a, &Learner::goalCountChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Learner::*)()>(_a, &Learner::activeGoalChanged, 8))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<LearnerProfile::LearningGoal*> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->identifier(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->imageUrl(); break;
        case 3: *reinterpret_cast<QList<LearnerProfile::LearningGoal*>*>(_v) = _t->goals(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setIdentifier(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *LearnerProfile::Learner::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LearnerProfile::Learner::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14LearnerProfile7LearnerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int LearnerProfile::Learner::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void LearnerProfile::Learner::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void LearnerProfile::Learner::imageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void LearnerProfile::Learner::identifierChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void LearnerProfile::Learner::goalAboutToBeAdded(LearningGoal * _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void LearnerProfile::Learner::goalAdded()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void LearnerProfile::Learner::goalAboutToBeRemoved(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void LearnerProfile::Learner::goalRemoved(Learner * _t1, LearningGoal * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void LearnerProfile::Learner::goalCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void LearnerProfile::Learner::activeGoalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
