/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<coursefiltermodel.h>)
#  include <coursefiltermodel.h>
#endif
#if __has_include(<coursemodel.h>)
#  include <coursemodel.h>
#endif
#if __has_include(<drawercoursetreemodel.h>)
#  include <drawercoursetreemodel.h>
#endif
#if __has_include(<drawertrainingactions.h>)
#  include <drawertrainingactions.h>
#endif
#if __has_include(<editorsession.h>)
#  include <editorsession.h>
#endif
#if __has_include(<isessionactions.h>)
#  include <isessionactions.h>
#endif
#if __has_include(<languagemodel.h>)
#  include <languagemodel.h>
#endif
#if __has_include(<languageresourcemodel.h>)
#  include <languageresourcemodel.h>
#endif
#if __has_include(<phonemegroupmodel.h>)
#  include <phonemegroupmodel.h>
#endif
#if __has_include(<phonememodel.h>)
#  include <phonememodel.h>
#endif
#if __has_include(<phonemeunitmodel.h>)
#  include <phonemeunitmodel.h>
#endif
#if __has_include(<phrasefiltermodel.h>)
#  include <phrasefiltermodel.h>
#endif
#if __has_include(<phraselistmodel.h>)
#  include <phraselistmodel.h>
#endif
#if __has_include(<phrasemodel.h>)
#  include <phrasemodel.h>
#endif
#if __has_include(<profilemodel.h>)
#  include <profilemodel.h>
#endif
#if __has_include(<skeletonmodel.h>)
#  include <skeletonmodel.h>
#endif
#if __has_include(<temporaryrecordingfile.h>)
#  include <temporaryrecordingfile.h>
#endif
#if __has_include(<trainingsession.h>)
#  include <trainingsession.h>
#endif
#if __has_include(<unitfiltermodel.h>)
#  include <unitfiltermodel.h>
#endif
#if __has_include(<unitmodel.h>)
#  include <unitmodel.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_artikulate()
{
    qmlRegisterModule("org.kde.artikulate", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<CourseFilterModel>("org.kde.artikulate", 254);
    qmlRegisterTypesAndRevisions<CourseModel>("org.kde.artikulate", 254);
    qmlRegisterTypesAndRevisions<DrawerCourseTreeModel>("org.kde.artikulate", 254);
    qmlRegisterEnum<DrawerCourseTreeModel::Roles>("DrawerCourseTreeModel::Roles");
    qmlRegisterTypesAndRevisions<DrawerTrainingActions>("org.kde.artikulate", 254);
    qmlRegisterEnum<DrawerTrainingActions::Roles>("DrawerTrainingActions::Roles");
    qmlRegisterTypesAndRevisions<EditorSession>("org.kde.artikulate", 254);
    qmlRegisterTypesAndRevisions<ISessionActions>("org.kde.artikulate", 254);
    qmlRegisterTypesAndRevisions<LanguageModel>("org.kde.artikulate", 254);
    qmlRegisterEnum<LanguageModel::LanguageResourceView>("LanguageModel::LanguageResourceView");
    qmlRegisterTypesAndRevisions<LanguageResourceModel>("org.kde.artikulate", 254);
    qmlRegisterTypesAndRevisions<PhonemeGroupModel>("org.kde.artikulate", 254);
    qmlRegisterTypesAndRevisions<PhonemeModel>("org.kde.artikulate", 254);
    qmlRegisterTypesAndRevisions<PhonemeUnitModel>("org.kde.artikulate", 254);
    qmlRegisterTypesAndRevisions<PhraseFilterModel>("org.kde.artikulate", 254);
    qmlRegisterEnum<PhraseFilterModel::SortOption>("PhraseFilterModel::SortOption");
    qmlRegisterTypesAndRevisions<PhraseListModel>("org.kde.artikulate", 254);
    qmlRegisterTypesAndRevisions<PhraseModel>("org.kde.artikulate", 254);
    qmlRegisterTypesAndRevisions<ProfileModel>("org.kde.artikulate", 254);
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QMetaType::fromType<QAbstractProxyModel *>().id();
    QMetaType::fromType<QSortFilterProxyModel *>().id();
    qmlRegisterTypesAndRevisions<SkeletonModel>("org.kde.artikulate", 254);
    qmlRegisterTypesAndRevisions<TemporaryRecordingFile>("org.kde.artikulate", 254);
    qmlRegisterTypesAndRevisions<TrainingSession>("org.kde.artikulate", 254);
    qmlRegisterTypesAndRevisions<UnitFilterModel>("org.kde.artikulate", 254);
    qmlRegisterTypesAndRevisions<UnitModel>("org.kde.artikulate", 254);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.artikulate", 254, 254);
}

static const QQmlModuleRegistration orgkdeartikulateRegistration("org.kde.artikulate", qml_register_types_org_kde_artikulate);
