/****************************************************************************
** Meta object code from reading C++ file 'contributorrepository.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../artikulate-26.04.0/src/core/contributorrepository.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'contributorrepository.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21ContributorRepositoryE_t {};
} // unnamed namespace

template <> constexpr inline auto ContributorRepository::qt_create_metaobjectdata<qt_meta_tag_ZN21ContributorRepositoryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ContributorRepository",
        "languageResourceAdded",
        "",
        "languageResourceAboutToBeAdded",
        "std::shared_ptr<ILanguage>",
        "repositoryChanged",
        "skeletonAdded",
        "skeletonAboutToBeAdded",
        "ICourse*",
        "skeletonRemoved",
        "skeletonAboutToBeRemoved",
        "languageCoursesChanged",
        "language",
        "ILanguage*",
        "LearnerProfile::LearningGoal*",
        "learningGoal",
        "createCourse",
        "IEditableCourse*",
        "std::shared_ptr<SkeletonResource>",
        "skeleton",
        "repositoryUrl",
        "QUrl"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'languageResourceAdded'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'languageResourceAboutToBeAdded'
        QtMocHelpers::SignalData<void(std::shared_ptr<ILanguage>, int)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'repositoryChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'skeletonAdded'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'skeletonAboutToBeAdded'
        QtMocHelpers::SignalData<void(ICourse *, int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'skeletonRemoved'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'skeletonAboutToBeRemoved'
        QtMocHelpers::SignalData<void(int, int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'languageCoursesChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'language'
        QtMocHelpers::MethodData<ILanguage *(LearnerProfile::LearningGoal *) const>(12, 2, QMC::AccessPublic, 0x80000000 | 13, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Method 'createCourse'
        QtMocHelpers::MethodData<IEditableCourse *(std::shared_ptr<ILanguage>, std::shared_ptr<SkeletonResource>)>(16, 2, QMC::AccessPublic, 0x80000000 | 17, {{
            { 0x80000000 | 4, 12 }, { 0x80000000 | 18, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'repositoryUrl'
        QtMocHelpers::PropertyData<QUrl>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ContributorRepository, qt_meta_tag_ZN21ContributorRepositoryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ContributorRepository::staticMetaObject = { {
    QMetaObject::SuperData::link<IEditableRepository::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ContributorRepositoryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ContributorRepositoryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21ContributorRepositoryE_t>.metaTypes,
    nullptr
} };

void ContributorRepository::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ContributorRepository *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->languageResourceAdded(); break;
        case 1: _t->languageResourceAboutToBeAdded((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<ILanguage>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 2: _t->repositoryChanged(); break;
        case 3: _t->skeletonAdded(); break;
        case 4: _t->skeletonAboutToBeAdded((*reinterpret_cast<std::add_pointer_t<ICourse*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 5: _t->skeletonRemoved(); break;
        case 6: _t->skeletonAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 7: _t->languageCoursesChanged(); break;
        case 8: { ILanguage* _r = _t->language((*reinterpret_cast<std::add_pointer_t<LearnerProfile::LearningGoal*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<ILanguage**>(_a[0]) = std::move(_r); }  break;
        case 9: { IEditableCourse* _r = _t->createCourse((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<ILanguage>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<std::shared_ptr<SkeletonResource>>>(_a[2])));
            if (_a[0]) *reinterpret_cast<IEditableCourse**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< LearnerProfile::LearningGoal* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ContributorRepository::*)()>(_a, &ContributorRepository::languageResourceAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ContributorRepository::*)(std::shared_ptr<ILanguage> , int )>(_a, &ContributorRepository::languageResourceAboutToBeAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ContributorRepository::*)()>(_a, &ContributorRepository::repositoryChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ContributorRepository::*)()>(_a, &ContributorRepository::skeletonAdded, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ContributorRepository::*)(ICourse * , int )>(_a, &ContributorRepository::skeletonAboutToBeAdded, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ContributorRepository::*)()>(_a, &ContributorRepository::skeletonRemoved, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ContributorRepository::*)(int , int )>(_a, &ContributorRepository::skeletonAboutToBeRemoved, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ContributorRepository::*)()>(_a, &ContributorRepository::languageCoursesChanged, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QUrl*>(_v) = _t->storageLocation(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setStorageLocation(*reinterpret_cast<QUrl*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ContributorRepository::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ContributorRepository::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ContributorRepositoryE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "IResourceRepository"))
        return static_cast< IResourceRepository*>(this);
    if (!strcmp(_clname, "IEditableRepository"))
        return static_cast< IEditableRepository*>(this);
    return IEditableRepository::qt_metacast(_clname);
}

int ContributorRepository::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = IEditableRepository::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void ContributorRepository::languageResourceAdded()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ContributorRepository::languageResourceAboutToBeAdded(std::shared_ptr<ILanguage> _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void ContributorRepository::repositoryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ContributorRepository::skeletonAdded()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ContributorRepository::skeletonAboutToBeAdded(ICourse * _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void ContributorRepository::skeletonRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ContributorRepository::skeletonAboutToBeRemoved(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void ContributorRepository::languageCoursesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
