/*
    SPDX-FileCopyrightText: 2015 Andreas Cord-Landwehr <cordlandwehr@kde.org>

    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
*/

#ifndef LIBLEARNER_DEBUG_H
#define LIBLEARNER_DEBUG_H

#include <QLoggingCategory>
Q_DECLARE_LOGGING_CATEGORY(LIBLEARNER_LOG)

#endif
