/****************************************************************************
** Meta object code from reading C++ file 'profilemanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../artikulate-26.04.0/liblearnerprofile/src/profilemanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'profilemanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14LearnerProfile14ProfileManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto LearnerProfile::ProfileManager::qt_create_metaobjectdata<qt_meta_tag_ZN14LearnerProfile14ProfileManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LearnerProfile::ProfileManager",
        "activeProfileChanged",
        "",
        "profileAdded",
        "Learner*",
        "profileAboutToBeRemoved",
        "profileRemoved",
        "profileCountChanged",
        "removeLearningGoal",
        "learner",
        "LearningGoal*",
        "goal",
        "addProfile",
        "LearnerProfile::Learner*",
        "name",
        "removeProfile",
        "profile",
        "index",
        "openImageFileDialog",
        "sync",
        "profileCount",
        "activeProfile"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'activeProfileChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'profileAdded'
        QtMocHelpers::SignalData<void(Learner *, int)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'profileAboutToBeRemoved'
        QtMocHelpers::SignalData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'profileRemoved'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'profileCountChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'removeLearningGoal'
        QtMocHelpers::SlotData<void(Learner *, LearningGoal *)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 9 }, { 0x80000000 | 10, 11 },
        }}),
        // Method 'addProfile'
        QtMocHelpers::MethodData<LearnerProfile::Learner *(const QString &)>(12, 2, QMC::AccessPublic, 0x80000000 | 13, {{
            { QMetaType::QString, 14 },
        }}),
        // Method 'removeProfile'
        QtMocHelpers::MethodData<void(LearnerProfile::Learner *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 9 },
        }}),
        // Method 'profile'
        QtMocHelpers::MethodData<LearnerProfile::Learner *(int)>(16, 2, QMC::AccessPublic, 0x80000000 | 13, {{
            { QMetaType::Int, 17 },
        }}),
        // Method 'openImageFileDialog'
        QtMocHelpers::MethodData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'sync'
        QtMocHelpers::MethodData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'sync'
        QtMocHelpers::MethodData<void(LearnerProfile::Learner *)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'profileCount'
        QtMocHelpers::PropertyData<int>(20, QMetaType::Int, QMC::DefaultPropertyFlags, 4),
        // property 'activeProfile'
        QtMocHelpers::PropertyData<LearnerProfile::Learner*>(21, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ProfileManager, qt_meta_tag_ZN14LearnerProfile14ProfileManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LearnerProfile::ProfileManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14LearnerProfile14ProfileManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14LearnerProfile14ProfileManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14LearnerProfile14ProfileManagerE_t>.metaTypes,
    nullptr
} };

void LearnerProfile::ProfileManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProfileManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->activeProfileChanged(); break;
        case 1: _t->profileAdded((*reinterpret_cast<std::add_pointer_t<Learner*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 2: _t->profileAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->profileRemoved(); break;
        case 4: _t->profileCountChanged(); break;
        case 5: _t->removeLearningGoal((*reinterpret_cast<std::add_pointer_t<Learner*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<LearningGoal*>>(_a[2]))); break;
        case 6: { LearnerProfile::Learner* _r = _t->addProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<LearnerProfile::Learner**>(_a[0]) = std::move(_r); }  break;
        case 7: _t->removeProfile((*reinterpret_cast<std::add_pointer_t<LearnerProfile::Learner*>>(_a[1]))); break;
        case 8: { LearnerProfile::Learner* _r = _t->profile((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<LearnerProfile::Learner**>(_a[0]) = std::move(_r); }  break;
        case 9: _t->openImageFileDialog(); break;
        case 10: _t->sync(); break;
        case 11: _t->sync((*reinterpret_cast<std::add_pointer_t<LearnerProfile::Learner*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< LearningGoal* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ProfileManager::*)()>(_a, &ProfileManager::activeProfileChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileManager::*)(Learner * , int )>(_a, &ProfileManager::profileAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileManager::*)(int )>(_a, &ProfileManager::profileAboutToBeRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileManager::*)()>(_a, &ProfileManager::profileRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileManager::*)()>(_a, &ProfileManager::profileCountChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->profileCount(); break;
        case 1: *reinterpret_cast<LearnerProfile::Learner**>(_v) = _t->activeProfile(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setActiveProfile(*reinterpret_cast<LearnerProfile::Learner**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *LearnerProfile::ProfileManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LearnerProfile::ProfileManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14LearnerProfile14ProfileManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int LearnerProfile::ProfileManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void LearnerProfile::ProfileManager::activeProfileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void LearnerProfile::ProfileManager::profileAdded(Learner * _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void LearnerProfile::ProfileManager::profileAboutToBeRemoved(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void LearnerProfile::ProfileManager::profileRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void LearnerProfile::ProfileManager::profileCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
